@@ -284,15 +284,19 @@ django.jQuery(function ($) {
     })
 
     if (visible) {
-      noRegionsMessage.hide()
       noPluginsMessage.hide()
     } else {
       if (ContentEditor.currentRegion) {
         noPluginsMessage.show()
-      } else {
-        noRegionsMessage.show()
+        machineEmptyMessage.hide()
       }
     }
+
+    if (ContentEditor.regions.length) {
+      noRegionsMessage.hide()
+    } else {
+      noRegionsMessage.show()
+    }
   }
 
   // Fetch the inline type from id
@@ -314,13 +318,13 @@ django.jQuery(function ($) {
           !pluginRegions[inlineType] ||
           $.inArray(ContentEditor.regions[i].key, pluginRegions[inlineType]) >=
             0) &&
-        ContentEditor.regions[i].key !== "_unknown_"
+        !/^_unknown_/.test(ContentEditor.regions[i].key)
       ) {
         regions.push(ContentEditor.regions[i])
       }
     }
 
-    if (regions.length < 2) return
+    if (regions.length < 2 && !/^_unknown_/.test($inline.data("region"))) return
 
     const select = buildDropdown(regions),
       regionInput = $inline.find(".field-region input")
